"""Generate a strong password which includes alphabets, numbers, special characters"""

__version__ = '1.1.3'

from .genpasswd import Password
from .functions import NoMultipleChoice, wanted_characters, include_characters, unwanted_characters, main
from .passgen import get_argument, gen_Pass, main



from . import functions


class Password:
    def __init__(self, length=False, ignore=False, only=False, include=False, repeat=False):
        self.length = length
        self.ignore = ignore
        self.only = only
        self.include = include
        self.repeat = repeat

    def genPass(self):
        return functions.main(Length=self.length, Unwanted=self.ignore, Only_char=self.only, Include=self.include, Repeat=self.repeat)
